Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(586)

Unified Diff: chrome/installer/util/google_update_settings.h

Issue 365133005: Refactor SetClientID such that metrics rather than crash backs up the client id in Google Update set (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix posix compile? Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/installer/util/google_update_settings.h
diff --git a/chrome/installer/util/google_update_settings.h b/chrome/installer/util/google_update_settings.h
index b7bf6125613e9c0e492566dd3be7474fc9d01b25..29cb8f2fdba826e239c56d564efb230cd4ef06ea 100644
--- a/chrome/installer/util/google_update_settings.h
+++ b/chrome/installer/util/google_update_settings.h
@@ -86,12 +86,12 @@ class GoogleUpdateSettings {
bool consented);
#endif
- // Returns the metrics id set in the registry (that can be used in crash
- // reports). If none found, returns empty string.
- static bool GetMetricsId(std::string* metrics_id);
+ // Returns the metrics client-id backed up in the registry. If none found,
grt (UTC plus 2) 2014/07/09 12:59:59 nit: "client-id" doesn't seem to be used elsewhere
gab 2014/07/09 14:42:39 Done.
+ // returns empty string.
+ static bool LoadMetricsClientId(std::string* metrics_id);
- // Sets the metrics id to be used in crash reports.
- static bool SetMetricsId(const std::string& metrics_id);
+ // Stores a backup of the metrics client-id in the registry.
+ static bool StoreMetricsClientId(const std::string& metrics_id);
// Sets the machine-wide EULA consented flag required on OEM installs.
// Returns false if the setting could not be recorded.

Powered by Google App Engine
This is Rietveld 408576698